@@ -24,7 +24,7 @@ import struct
 import traceback
 import weakref
 
-from PyQt5.QtCore import pyqtSignal, QObject, QSocketNotifier
+from PyQt6.QtCore import pyqtSignal, QObject, QSocketNotifier
 
 def recvall(sock, remaining):
     alldata = bytearray()
@@ -57,7 +57,7 @@ class MarkupNotAvailableError(Exception):
     pass
 
 def _indent(text, prefix):
-    return ''.join(('%s%s\n' % (prefix, line) for line in text.splitlines()))
+    return ''.join('%s%s\n' % (prefix, line) for line in text.splitlines())
 
 def _converter_process_func(conn_parent, conn_child):
     conn_parent.close()
@@ -117,8 +117,7 @@ class ConverterProcess(QObject):
 
         # TODO: figure out which of the two sockets should be set to 
         #       inheritable and which should be passed to the child
-        if hasattr(conn_child, 'set_inheritable'):
-            conn_child.set_inheritable(True)
+        conn_child.set_inheritable(True)
 
         # Use a local variable for child so that we can talk to the child in
         # on_finalize without needing a reference to self
