@@ -1,7 +1,7 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 #
 # This file is part of ReText
-# Copyright: 2012-2022 Dmitry Shachnev
+# Copyright: 2012-2024 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ import weakref
 from markups import MarkdownMarkup, ReStructuredTextMarkup, TextileMarkup
 from ReText import globalSettings, settings, tablemode
 
-from PyQt6.QtCore import pyqtSignal, QFileInfo, QPoint, QRect, QSize, Qt
+from PyQt6.QtCore import pyqtSignal, QFileInfo, QPoint, QPointF, QRect, QSize, Qt
 from PyQt6.QtGui import QAction, QColor, QImage, QKeyEvent, QMouseEvent, QPainter, \
 QPalette, QTextCursor, QTextFormat, QWheelEvent, QGuiApplication
 from PyQt6.QtWidgets import QApplication, QFileDialog, QLabel, QTextEdit, QWidget
@@ -521,6 +521,11 @@ class ReTextEdit(QTextEdit):
 		characterCount = len(text)
 		self.statistics = (wordCount, alphaNumCount, characterCount)
 
+	def inputMethodEvent(self, event):
+		# Empty events cause layout issues (issue #597), so ignore them.
+		if event.preeditString() or event.commitString() or event.attributes():
+			super().inputMethodEvent(event)
+
 
 class LineNumberArea(QWidget):
 	def __init__(self, editor):
@@ -608,7 +613,7 @@ class InfoArea(QLabel):
 		self.setPalette(palette)
 
 	def mousePressEvent(self, event):
-		pos = self.mapToParent(event.pos())
+		pos: QPointF = self.mapToParent(event.position())
 		pos.setX(pos.x() - self.editor.lineNumberAreaWidth())
 		newEvent = QMouseEvent(event.type(), pos,
 		                       event.button(), event.buttons(),
