@@ -1,7 +1,7 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 #
 # This file is part of ReText
-# Copyright: 2015-2022 Dmitry Shachnev
+# Copyright: 2015-2023 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,6 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from os.path import exists, splitext
+import locale
 import time
 from markups import get_markup_for_file_name, find_markup_class_by_name
 from markups.common import MODULE_HOME_PAGE
@@ -281,14 +282,14 @@ class ReTextTab(QSplitter):
 			QTimer.singleShot(500, self.startPendingConversion)
 
 	def startPendingConversion(self):
-			self.previewOutdated = False
+		self.previewOutdated = False
 
-			requested_extensions = ['ReText.mdx_posmap'] if globalSettings.syncScroll else []
-			self.converterProcess.start_conversion(self.getActiveMarkupClass().name,
-			                                       self.fileName,
-			                                       requested_extensions,
-			                                       self.editBox.toPlainText(),
-			                                       QDir.currentPath())
+		requested_extensions = ['ReText.mdx_posmap'] if globalSettings.syncScroll else []
+		self.converterProcess.start_conversion(self.getActiveMarkupClass().name,
+		                                       self.fileName,
+		                                       requested_extensions,
+		                                       self.editBox.toPlainText(),
+		                                       QDir.currentPath())
 
 	def updateBoxesVisibility(self):
 		self.editBox.setVisible(self.previewState < PreviewNormal)
@@ -305,9 +306,9 @@ class ReTextTab(QSplitter):
 		self.triggerPreviewUpdate()
 		self.updateBoxesVisibility()
 
-	def detectFileEncoding(self, fileName):
+	def detectEncoding(self, raw: bytes):
 		'''
-		Detect content encoding of specific file.
+		Detect content encoding of the given data.
 
 		It will return None if it can't determine the encoding.
 		'''
@@ -316,12 +317,6 @@ class ReTextTab(QSplitter):
 		except ImportError:
 			return
 
-		try:
-			with open(fileName, 'rb') as inputFile:
-				raw = inputFile.read(2048)
-		except OSError:
-			return None
-
 		result = chardet.detect(raw)
 		if result['confidence'] > 0.9:
 			if result['encoding'].lower() == 'ascii':
@@ -335,17 +330,21 @@ class ReTextTab(QSplitter):
 		previousFileName = self._fileName
 		fileName = fileName or self._fileName
 
+		try:
+			with open(fileName, 'rb') as openfile:
+				data = openfile.read()
+		except OSError as ex:
+			QMessageBox.warning(self, '', str(ex))
+			return
+
 		# Only try to detect encoding if it is not specified
 		if encoding is None and globalSettings.detectEncoding:
-			encoding = self.detectFileEncoding(fileName)
+			encoding = self.detectEncoding(data[:2048])
 		encoding = encoding or globalSettings.defaultCodec or None
 
-		# TODO: why do we open the file twice: for detecting encoding
-		# and for actual read? Can we open it just once?
 		try:
-			with open(fileName, encoding=encoding) as openfile:
-				text = openfile.read()
-		except (OSError, UnicodeDecodeError, LookupError) as ex:
+			text = data.decode(encoding or locale.getpreferredencoding(False))
+		except (UnicodeDecodeError, LookupError) as ex:
 			QMessageBox.warning(self, '', str(ex))
 			return
 
@@ -384,9 +383,14 @@ class ReTextTab(QSplitter):
 		encoding = self.editBox.document().property("encoding")
 		encoding = encoding or globalSettings.defaultCodec or None
 		try:
-			with open(fileName, 'w', encoding=encoding) as savefile:
-				savefile.write(text)
-		except (OSError, UnicodeEncodeError, LookupError) as ex:
+			data = text.encode(encoding or locale.getpreferredencoding(False))
+		except (UnicodeEncodeError, LookupError) as ex:
+			QMessageBox.warning(self, '', str(ex))
+			return False
+		try:
+			with open(fileName, 'wb') as savefile:
+				savefile.write(data)
+		except OSError as ex:
 			QMessageBox.warning(self, '', str(ex))
 			return False
 		return True
