@@ -1,7 +1,7 @@
 # vim: ts=8:sts=8:sw=8:noexpandtab
 #
 # This file is part of ReText
-# Copyright: 2012-2021 Dmitry Shachnev
+# Copyright: 2012-2024 Dmitry Shachnev
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,10 +23,10 @@ from subprocess import Popen
 import warnings
 
 from ReText import (getBundledIcon, app_version, globalSettings,
-                    readListFromSettings, writeListToSettings, datadirs)
-from ReText.tab import (ReTextTab, ReTextWebKitPreview, ReTextWebEnginePreview,
+                    readListFromSettings, writeListToSettings)
+from ReText.tab import (ReTextTab, ReTextWebEnginePreview,
                         PreviewDisabled, PreviewNormal, PreviewLive)
-from ReText.dialogs import HtmlDialog, LocaleDialog
+from ReText.dialogs import EncodingDialog, HtmlDialog, LocaleDialog
 from ReText.config import ConfigDialog, setIconThemeFromSettings
 from ReText.tabledialog import InsertTableDialog
 
@@ -40,26 +40,23 @@ try:
 except ImportError:
 	enchant = None
 
-from PyQt5.QtCore import QDir, QFile, QFileInfo, QFileSystemWatcher, \
- QIODevice, QLocale, QMarginsF, QTextCodec, QTextStream, QTimer, QUrl, Qt, pyqtSlot
-from PyQt5.QtGui import QColor, QDesktopServices, QIcon, \
- QKeySequence, QPageLayout, QPageSize, QPagedPaintDevice, QPalette, \
- QTextDocument, QTextDocumentWriter
-from PyQt5.QtWidgets import QAction, QActionGroup, QApplication, QCheckBox, \
- QComboBox, QDialog, QFileDialog, QFileSystemModel, QFontDialog, \
- QInputDialog, QLineEdit, QMainWindow, QMenu, QMessageBox, QSplitter, QTabWidget, \
- QToolBar, QToolButton, QTreeView
-from PyQt5.QtPrintSupport import QPrintDialog, QPrintPreviewDialog, QPrinter
+from PyQt6.QtCore import QDir, QFile, QFileInfo, QFileSystemWatcher, \
+ QIODevice, QLocale, QMarginsF, QStandardPaths, QTextStream, QTimer, \
+ QUrl, Qt, pyqtSlot
+from PyQt6.QtGui import QAction, QActionGroup, QColor, QDesktopServices, \
+ QFileSystemModel, QIcon, QKeySequence, QPageLayout, QPageSize, \
+ QPalette, QTextDocument, QTextDocumentWriter
+from PyQt6.QtWidgets import QApplication, QCheckBox, QComboBox, QDialog, \
+ QFileDialog, QFontDialog, QInputDialog, QLineEdit, QMainWindow, QMenu, \
+ QMessageBox, QSplitter, QTabWidget, QToolBar, QToolButton, QTreeView
+from PyQt6.QtPrintSupport import QPrintDialog, QPrintPreviewDialog, QPrinter
 
 class ReTextWindow(QMainWindow):
 	def __init__(self, parent=None):
 		QMainWindow.__init__(self, parent)
 		self.resize(950, 700)
 		qApp = QApplication.instance()
-		if hasattr(self, 'screen'):  # Available since Qt 5.14
-			screenRect = self.screen().geometry()
-		else:
-			screenRect = qApp.desktop().screenGeometry()
+		screenRect = self.screen().geometry()
 		if globalSettings.windowGeometry:
 			self.restoreGeometry(globalSettings.windowGeometry)
 		else:
@@ -115,9 +112,9 @@ class ReTextWindow(QMainWindow):
 		self.actionSaveAs = self.act(self.tr('Save as'), 'document-save-as',
 			self.saveFileAs, shct=QKeySequence.StandardKey.SaveAs)
 		self.actionNextTab = self.act(self.tr('Next tab'), 'go-next',
-			lambda: self.switchTab(1), shct=Qt.Modifier.CTRL+Qt.Key.Key_PageDown)
+			lambda: self.switchTab(1), shct=Qt.Modifier.CTRL | Qt.Key.Key_PageDown)
 		self.actionPrevTab = self.act(self.tr('Previous tab'), 'go-previous',
-			lambda: self.switchTab(-1), shct=Qt.Modifier.CTRL+Qt.Key.Key_PageUp)
+			lambda: self.switchTab(-1), shct=Qt.Modifier.CTRL | Qt.Key.Key_PageUp)
 		self.actionCloseCurrentTab = self.act(self.tr('Close tab'), 'window-close',
 			lambda: self.closeTab(self.ind), shct=QKeySequence.StandardKey.Close)
 		self.actionPrint = self.act(self.tr('Print'), 'document-print',
@@ -132,9 +129,9 @@ class ReTextWindow(QMainWindow):
 		self.actionSearch = self.act(self.tr('Find text'), 'edit-find',
 			self.search, shct=QKeySequence.StandardKey.Find)
 		self.actionGoToLine = self.act(self.tr('Go to line'),
-			trig=self.goToLine, shct=Qt.Modifier.CTRL+Qt.Key.Key_G)
+			trig=self.goToLine, shct=Qt.Modifier.CTRL | Qt.Key.Key_G)
 		self.searchBar.visibilityChanged.connect(self.searchBarVisibilityChanged)
-		self.actionPreview = self.act(self.tr('Preview'), shct=Qt.Modifier.CTRL+Qt.Key.Key_E,
+		self.actionPreview = self.act(self.tr('Preview'), shct=Qt.Modifier.CTRL | Qt.Key.Key_E,
 			trigbool=self.preview)
 		if QIcon.hasThemeIcon('document-preview'):
 			self.actionPreview.setIcon(QIcon.fromTheme('document-preview'))
@@ -144,20 +141,20 @@ class ReTextWindow(QMainWindow):
 			self.actionPreview.setIcon(QIcon.fromTheme('x-office-document'))
 		else:
 			self.actionPreview.setIcon(QIcon(getBundledIcon('document-preview')))
-		self.actionLivePreview = self.act(self.tr('Live preview'), shct=Qt.Modifier.CTRL+Qt.Key.Key_L,
+		self.actionLivePreview = self.act(self.tr('Live preview'), shct=Qt.Modifier.CTRL | Qt.Key.Key_L,
 		trigbool=self.enableLivePreview)
 		menuPreview = QMenu()
 		menuPreview.addAction(self.actionLivePreview)
 		self.actionInsertTable = self.act(self.tr('Insert table'),
 			trig=lambda: self.insertFormatting('table'))
 		self.actionTableMode = self.act(self.tr('Table editing mode'),
-			shct=Qt.Modifier.CTRL+Qt.Key.Key_T,
+			shct=Qt.Modifier.CTRL | Qt.Key.Key_T,
 			trigbool=lambda x: self.currentTab.editBox.enableTableMode(x))
 		self.actionInsertImages = self.act(self.tr('Insert images by file path'),
 			trig=lambda: self.insertImages())
 		if ReTextFakeVimHandler:
 			self.actionFakeVimMode = self.act(self.tr('FakeVim mode'),
-				shct=Qt.Modifier.CTRL+Qt.Modifier.ALT+Qt.Key.Key_V, trigbool=self.enableFakeVimMode)
+				shct=Qt.Modifier.CTRL | Qt.Modifier.ALT | Qt.Key.Key_V, trigbool=self.enableFakeVimMode)
 			if globalSettings.useFakeVim:
 				self.actionFakeVimMode.setChecked(True)
 				self.enableFakeVimMode(True)
@@ -185,29 +182,24 @@ class ReTextWindow(QMainWindow):
 		self.actionPaste = self.act(self.tr('Paste'), 'edit-paste',
 			lambda: self.currentTab.editBox.paste(), shct=QKeySequence.StandardKey.Paste)
 		self.actionPasteImage = self.act(self.tr('Paste image'), 'edit-paste',
-			lambda: self.currentTab.editBox.pasteImage(), shct=Qt.Modifier.CTRL+Qt.Modifier.SHIFT+Qt.Key.Key_V)
+			lambda: self.currentTab.editBox.pasteImage(), shct=Qt.Modifier.CTRL | Qt.Modifier.SHIFT | Qt.Key.Key_V)
 		self.actionMoveUp = self.act(self.tr('Move line up'), 'go-up',
-			lambda: self.currentTab.editBox.moveLineUp(), shct=Qt.Modifier.ALT+Qt.Key.Key_Up)
+			lambda: self.currentTab.editBox.moveLineUp(), shct=Qt.Modifier.ALT | Qt.Key.Key_Up)
 		self.actionMoveDown = self.act(self.tr('Move line down'), 'go-down',
-			lambda: self.currentTab.editBox.moveLineDown(), shct=Qt.Modifier.ALT+Qt.Key.Key_Down)
+			lambda: self.currentTab.editBox.moveLineDown(), shct=Qt.Modifier.ALT | Qt.Key.Key_Down)
 		self.actionUndo.setEnabled(False)
 		self.actionRedo.setEnabled(False)
 		self.actionCopy.setEnabled(False)
 		self.actionCut.setEnabled(False)
 		qApp.clipboard().dataChanged.connect(self.clipboardDataChanged)
 		self.clipboardDataChanged()
-		if enchant is not None:
-			self.actionEnableSC = self.act(self.tr('Enable'), trigbool=self.enableSpellCheck)
-			self.actionSetLocale = self.act(self.tr('Set locale'), trig=self.changeLocale)
-		self.actionWebKit = self.act(self.tr('Use WebKit renderer'), trigbool=self.enableWebKit)
-		if ReTextWebKitPreview is None:
-			globalSettings.useWebKit = False
-			self.actionWebKit.setEnabled(False)
-		self.actionWebKit.setChecked(globalSettings.useWebKit)
+		self.actionEnableSC = self.act(self.tr('Enable'), trigbool=self.enableSpellCheck)
+		self.actionSetLocale = self.act(self.tr('Set locale'), trig=self.changeLocale)
 		self.actionWebEngine = self.act(self.tr('Use WebEngine (Chromium) renderer'),
 			trigbool=self.enableWebEngine)
 		if ReTextWebEnginePreview is None:
 			globalSettings.useWebEngine = False
+			self.actionWebEngine.setEnabled(False)
 		self.actionWebEngine.setChecked(globalSettings.useWebEngine)
 		self.actionShow = self.act(self.tr('Show directory'), 'system-file-manager', self.showInDir)
 		self.actionFind = self.act(self.tr('Next'), 'go-next', self.find,
@@ -224,6 +216,7 @@ class ReTextWindow(QMainWindow):
 			shct=QKeySequence.StandardKey.Cancel)
 		self.actionCloseSearch.setPriority(QAction.Priority.LowPriority)
 		self.actionHelp = self.act(self.tr('Get help online'), 'help-contents', self.openHelp)
+		self.actionWhatsNew = self.act(self.tr("What's new"), trig=self.openReleases)
 		self.aboutWindowTitle = self.tr('About ReText')
 		self.actionAbout = self.act(self.aboutWindowTitle, 'help-about', self.aboutDialog)
 		self.actionAbout.setMenuRole(QAction.MenuRole.AboutRole)
@@ -257,10 +250,7 @@ class ReTextWindow(QMainWindow):
 		self.formattingBox = QComboBox(self.editBar)
 		self.formattingBox.addItem(self.tr('Formatting'))
 		self.formattingBox.addItems(self.usefulTags)
-		if hasattr(self.formattingBox, 'textActivated'):  # Available since Qt 5.14
-			self.formattingBox.textActivated.connect(self.insertFormatting)
-		else:
-			self.formattingBox.activated[str].connect(self.insertFormatting)
+		self.formattingBox.textActivated.connect(self.insertFormatting)
 		self.symbolBox = QComboBox(self.editBar)
 		self.symbolBox.addItem(self.tr('Symbols'))
 		self.symbolBox.addItems(self.usefulChars)
@@ -326,10 +316,7 @@ class ReTextWindow(QMainWindow):
 		menuFormat.addAction(self.actionBold)
 		menuFormat.addAction(self.actionItalic)
 		menuFormat.addAction(self.actionUnderline)
-		if ReTextWebKitPreview is not None or ReTextWebEnginePreview is None:
-			menuEdit.addAction(self.actionWebKit)
-		else:
-			menuEdit.addAction(self.actionWebEngine)
+		menuEdit.addAction(self.actionWebEngine)
 		menuEdit.addSeparator()
 		menuEdit.addAction(self.actionViewHtml)
 		menuEdit.addAction(self.actionPreview)
@@ -343,6 +330,7 @@ class ReTextWindow(QMainWindow):
 		menuEdit.addAction(self.actionFullScreen)
 		menuEdit.addAction(self.actionConfig)
 		menuHelp.addAction(self.actionHelp)
+		menuHelp.addAction(self.actionWhatsNew)
 		menuHelp.addSeparator()
 		menuHelp.addAction(self.actionAbout)
 		menuHelp.addAction(self.actionAboutQt)
@@ -390,18 +378,17 @@ class ReTextWindow(QMainWindow):
 		self.searchBar.addAction(self.actionCloseSearch)
 		self.searchBar.setToolButtonStyle(Qt.ToolButtonStyle.ToolButtonTextBesideIcon)
 		self.searchBar.setVisible(False)
-		self.autoSaveEnabled = globalSettings.autoSave
-		if self.autoSaveEnabled:
-			timer = QTimer(self)
-			timer.start(60000)
-			timer.timeout.connect(self.saveAll)
+		self.autoSaveTimer = QTimer(self)
+		self.autoSaveTimer.timeout.connect(self.saveAll)
+		if globalSettings.autoSave:
+			self.autoSaveTimer.start(60000)
 		self.ind = None
 		if enchant is not None:
-			self.sl = globalSettings.spellCheckLocale
-			try:
-				enchant.Dict(self.sl or None)
-			except enchant.errors.Error as e:
-				warnings.warn(str(e), RuntimeWarning)
+			self.spellCheckLanguages = globalSettings.spellCheckLocale
+			languages, errors = self.getSpellCheckDictionaries()
+			for error in errors:
+				warnings.warn(error, RuntimeWarning)
+			if not languages:
 				globalSettings.spellCheck = False
 			if globalSettings.spellCheck:
 				self.actionEnableSC.setChecked(True)
@@ -494,7 +481,7 @@ class ReTextWindow(QMainWindow):
 
 	def updateTabTitle(self, ind, tab):
 		changed = tab.editBox.document().isModified()
-		if changed and not self.autoSaveActive(tab):
+		if changed:
 			title = tab.getBaseName() + '*'
 		else:
 			title = tab.getBaseName()
@@ -518,7 +505,7 @@ class ReTextWindow(QMainWindow):
 				self.setWindowFilePath('')
 				self.setWindowTitle(self.tr('New document') + '[*]')
 
-			canReload = bool(tab.fileName) and not self.autoSaveActive(tab)
+			canReload = bool(tab.fileName) and not tab.autoSaveActive()
 			self.actionSetEncoding.setEnabled(canReload)
 			self.actionReload.setEnabled(canReload)
 
@@ -545,8 +532,6 @@ class ReTextWindow(QMainWindow):
 
 		if tab == self.currentTab:
 			changed = tab.editBox.document().isModified()
-			if self.autoSaveActive(tab):
-				changed = False
 			self.actionSave.setEnabled(changed)
 			self.updateTabTitle(self.ind, tab)
 			self.setWindowModified(changed)
@@ -611,22 +596,22 @@ class ReTextWindow(QMainWindow):
 		self.tabActiveMarkupChanged(self.currentTab)
 
 	def changeEditorFont(self):
-		font, ok = QFontDialog.getFont(globalSettings.editorFont, self)
+		font, ok = QFontDialog.getFont(globalSettings.getEditorFont(), self)
 		if ok:
 			self.setEditorFont(font)
 
 	def setEditorFont(self, font):
-		globalSettings.editorFont = font
+		globalSettings.editorFont = font.toString()
 		for tab in self.iterateTabs():
 			tab.editBox.updateFont()
 
 	def changePreviewFont(self):
-		font, ok = QFontDialog.getFont(globalSettings.font, self)
+		font, ok = QFontDialog.getFont(globalSettings.getPreviewFont(), self)
 		if ok:
 			self.setPreviewFont(font)
 
 	def setPreviewFont(self, font):
-		globalSettings.font = font
+		globalSettings.font = font.toString()
 		for tab in self.iterateTabs():
 			tab.triggerPreviewUpdate()
 
@@ -644,14 +629,7 @@ class ReTextWindow(QMainWindow):
 		self.currentTab.updateBoxesVisibility()
 		self.currentTab.triggerPreviewUpdate()
 
-	def enableWebKit(self, enable):
-		globalSettings.useWebKit = enable
-		globalSettings.useWebEngine = False
-		for tab in self.iterateTabs():
-			tab.rebuildPreviewBox()
-
 	def enableWebEngine(self, enable):
-		globalSettings.useWebKit = False
 		globalSettings.useWebEngine = enable
 		for tab in self.iterateTabs():
 			tab.rebuildPreviewBox()
@@ -680,36 +658,40 @@ class ReTextWindow(QMainWindow):
 		else:
 			FakeVimMode.exit(self)
 
-	def enableSpellCheck(self, yes):
-		try:
-			dict = enchant.Dict(self.sl or None)
-		except enchant.errors.Error as e:
-			QMessageBox.warning(self, '', str(e))
-			self.actionEnableSC.setChecked(False)
-			yes = False
-		self.setAllDictionaries(dict if yes else None)
-		globalSettings.spellCheck = yes
+	def getSpellCheckDictionaries(self):
+		"""Returns the list of languages and the list of errors."""
+		dictionaries = []
+		errors = []
+		if enchant is None:
+			return dictionaries, errors
+		for language in self.spellCheckLanguages.split(','):
+			try:
+				dict = enchant.Dict(language.strip() or None)
+			except enchant.errors.Error as e:
+				errors.append(str(e))
+			else:
+				dictionaries.append(dict)
+		return dictionaries, errors
 
-	def setAllDictionaries(self, dictionary):
+	def enableSpellCheck(self, yes):
+		dictionaries = []
+		if yes:
+			dictionaries, errors = self.getSpellCheckDictionaries()
+			if errors:
+				QMessageBox.warning(self, '', '\n'.join(errors))
 		for tab in self.iterateTabs():
-			hl = tab.highlighter
-			hl.dictionary = dictionary
-			hl.rehighlight()
+			tab.highlighter.dictionaries = dictionaries
+			tab.highlighter.rehighlight()
+		globalSettings.spellCheck = bool(dictionaries)
+		self.actionEnableSC.setChecked(bool(dictionaries))
 
 	def changeLocale(self):
-		localedlg = LocaleDialog(self, defaultText=self.sl)
+		localedlg = LocaleDialog(self, defaultText=self.spellCheckLanguages)
 		if localedlg.exec() != QDialog.DialogCode.Accepted:
 			return
-		sl = localedlg.localeEdit.text()
-		try:
-			enchant.Dict(sl or None)
-		except enchant.errors.Error as e:
-			QMessageBox.warning(self, '', str(e))
-		else:
-			self.sl = sl or None
-			self.enableSpellCheck(self.actionEnableSC.isChecked())
-			if localedlg.checkBox.isChecked():
-				globalSettings.spellCheckLocale = sl
+		self.spellCheckLanguages = localedlg.localeEdit.text()
+		self.enableSpellCheck(True)
+		globalSettings.spellCheckLocale = self.spellCheckLanguages
 
 	def search(self):
 		self.searchBar.setVisible(True)
@@ -725,7 +707,7 @@ class ReTextWindow(QMainWindow):
 			self.searchEdit.setFocus(Qt.FocusReason.ShortcutFocusReason)
 
 	def find(self, back=False, replace=False):
-		flags = QTextDocument.FindFlags()
+		flags = QTextDocument.FindFlag(0)
 		if back:
 			flags |= QTextDocument.FindFlag.FindBackward
 		if self.csBox.isChecked():
@@ -800,8 +782,10 @@ class ReTextWindow(QMainWindow):
 
 	def getExportExtensionsList(self):
 		extensions = []
-		for extsprefix in datadirs:
-			extsdir = QDir(extsprefix+'/export-extensions/')
+		datadirs = QStandardPaths.standardLocations(
+			QStandardPaths.StandardLocation.GenericDataLocation)
+		for datadir in datadirs:
+			extsdir = QDir(os.path.join(datadir, 'retext', 'export-extensions'))
 			if extsdir.exists():
 				for fileInfo in extsdir.entryInfoList(['*.desktop', '*.ini'],
 				QDir.Filter.Files | QDir.Filter.Readable):
@@ -905,13 +889,9 @@ class ReTextWindow(QMainWindow):
 	def showEncodingDialog(self):
 		if not self.maybeSave(self.ind):
 			return
-		codecsSet = set(bytes(QTextCodec.codecForName(alias).name())
-		                for alias in QTextCodec.availableCodecs())
-		encoding, ok = QInputDialog.getItem(self, '',
-			self.tr('Select file encoding from the list:'),
-			[bytes(b).decode() for b in sorted(codecsSet)],
-			0, False)
-		if ok:
+		dialog = EncodingDialog(self)
+		if dialog.exec() == QDialog.DialogCode.Accepted:
+			encoding = dialog.encodingEdit.text()
 			self.currentTab.readTextFromFile(None, encoding)
 
 	def saveFileAs(self):
@@ -919,8 +899,7 @@ class ReTextWindow(QMainWindow):
 
 	def saveAll(self):
 		for tab in self.iterateTabs():
-			if (tab.fileName and tab.editBox.document().isModified()
-				and QFileInfo(tab.fileName).isWritable()):
+			if tab.autoSaveActive() and tab.editBox.document().isModified():
 				tab.saveTextToFile()
 
 	def saveFile(self, dlg=False):
@@ -956,14 +935,11 @@ class ReTextWindow(QMainWindow):
 						QMessageBox.warning(self, "",
 							self.tr("Cannot save to file which is open in another tab!"))
 						return False
-				self.actionSetEncoding.setDisabled(self.autoSaveActive())
+				self.actionSetEncoding.setDisabled(self.currentTab.autoSaveActive())
 		if fileNameToSave:
 			if self.currentTab.saveTextToFile(fileNameToSave):
 				self.moveToTopOfRecentFileList(self.currentTab.fileName)
 				return True
-			else:
-				QMessageBox.warning(self, '',
-				self.tr("Cannot save to file because it is read-only!"))
 		return False
 
 	def saveHtml(self, fileName):
@@ -973,23 +949,19 @@ class ReTextWindow(QMainWindow):
 			_, htmltext, _ = self.currentTab.getDocumentForExport(webenv=True)
 		except Exception:
 			return self.printError()
-		htmlFile = QFile(fileName)
-		result = htmlFile.open(QIODevice.OpenModeFlag.WriteOnly)
-		if not result:
-			QMessageBox.warning(self, '',
-				self.tr("Cannot save to file because it is read-only!"))
-			return
-		html = QTextStream(htmlFile)
-		if globalSettings.defaultCodec:
-			html.setCodec(globalSettings.defaultCodec)
-		html << htmltext
-		htmlFile.close()
+
+		encoding = globalSettings.defaultCodec or None
+		try:
+			with open(fileName, 'w', encoding=encoding) as htmlFile:
+				htmlFile.write(htmltext)
+		except (OSError, UnicodeEncodeError, LookupError) as ex:
+			QMessageBox.warning(self, '', str(ex))
 
 	def textDocument(self, title, htmltext):
 		td = QTextDocument()
 		td.setMetaInformation(QTextDocument.MetaInformation.DocumentTitle, title)
 		td.setHtml(htmltext)
-		td.setDefaultFont(globalSettings.font)
+		td.setDefaultFont(globalSettings.getPreviewFont())
 		return td
 
 	def saveOdf(self):
@@ -1015,8 +987,6 @@ class ReTextWindow(QMainWindow):
 			self.saveHtml(fileName)
 
 	def getDocumentForPrint(self, title, htmltext, preview):
-		if globalSettings.useWebKit:
-			return preview
 		try:
 			return self.textDocument(title, htmltext)
 		except Exception:
@@ -1029,7 +999,7 @@ class ReTextWindow(QMainWindow):
 		if globalSettings.paperSize:
 			pageSize = self.getPageSizeByName(globalSettings.paperSize)
 			if pageSize is not None:
-				printer.setPaperSize(pageSize)
+				printer.setPageSize(pageSize)
 			else:
 				QMessageBox.warning(self, '',
 					self.tr('Unrecognized paperSize setting "%s".') %
@@ -1037,24 +1007,13 @@ class ReTextWindow(QMainWindow):
 		return printer
 
 	def getPageSizeByName(self, pageSizeName):
-		""" Returns a validated PageSize instance corresponding to the given
+		""" Returns a validated QPageSize instance corresponding to the given
 		name. Returns None if the name is not a valid PageSize.
 		"""
-		pageSize = None
-
-		lowerCaseNames = {pageSize.lower(): pageSize for pageSize in
-		                  self.availablePageSizes()}
-		if pageSizeName.lower() in lowerCaseNames:
-			pageSize = getattr(QPagedPaintDevice, lowerCaseNames[pageSizeName.lower()])
-
-		return pageSize
-
-	def availablePageSizes(self):
-		""" List available page sizes. """
-
-		sizes = [x for x in dir(QPagedPaintDevice)
-		         if type(getattr(QPagedPaintDevice, x)) == QPagedPaintDevice.PageSize]
-		return sizes
+		sizesByName = {e.name.lower(): e for e in QPageSize.PageSizeId}
+		sizeId = sizesByName.get(pageSizeName.lower())
+		if sizeId is not None:
+			return QPageSize(sizeId)
 
 	def savePdf(self):
 		fileName = QFileDialog.getSaveFileName(self,
@@ -1132,11 +1091,6 @@ class ReTextWindow(QMainWindow):
 			+ '\n' + errorstr)
 		QFile(tmpname).remove()
 
-	def autoSaveActive(self, tab=None):
-		tab = tab if tab else self.currentTab
-		return bool(self.autoSaveEnabled and tab.fileName and
-			    QFileInfo(tab.fileName).isWritable())
-
 	def clipboardDataChanged(self):
 		mimeData = QApplication.instance().clipboard().mimeData()
 		if mimeData is not None:
@@ -1218,31 +1172,30 @@ class ReTextWindow(QMainWindow):
 			# File was not modified in ReText, reload silently
 			tab.readTextFromFile()
 		else:
+			tab.forceDisableAutoSave = True
 			self.tabWidget.setCurrentWidget(tab)
 			text = self.tr(
 				'This document has been modified by other application.\n'
 				'Do you want to reload the file (this will discard all '
 				'your changes)?\n')
-			if self.autoSaveEnabled:
+			if globalSettings.autoSave:
 				text += self.tr(
-					'If you choose to not reload the file, auto save mode will '
-					'be disabled for this session to prevent data loss.')
+					'Automatic saving has been temporarily disabled for this '
+					'tab to prevent data loss. It will be re-enabled when you '
+					'reload the file or save it manually.')
 			messageBox = QMessageBox(QMessageBox.Icon.Warning, '', text)
 			reloadButton = messageBox.addButton(self.tr('Reload'), QMessageBox.ButtonRole.YesRole)
 			messageBox.addButton(QMessageBox.StandardButton.Cancel)
 			messageBox.exec()
 			if messageBox.clickedButton() is reloadButton:
 				tab.readTextFromFile()
-			else:
-				self.autoSaveEnabled = False
-				tab.editBox.document().setModified(True)
 		if fileName not in self.fileSystemWatcher.files():
 			# https://github.com/retext-project/retext/issues/137
 			self.fileSystemWatcher.addPath(fileName)
 
 	def maybeSave(self, ind):
 		tab = self.tabWidget.widget(ind)
-		if self.autoSaveActive(tab):
+		if tab.autoSaveActive():
 			tab.saveTextToFile()
 			return True
 		if not tab.editBox.document().isModified():
@@ -1303,12 +1256,15 @@ class ReTextWindow(QMainWindow):
 	def openHelp(self):
 		QDesktopServices.openUrl(QUrl('https://github.com/retext-project/retext/wiki'))
 
+	def openReleases(self):
+		QDesktopServices.openUrl(QUrl('https://github.com/retext-project/retext/releases'))
+
 	def aboutDialog(self):
 		QMessageBox.about(self, self.aboutWindowTitle,
 		'<p><b>' + (self.tr('ReText %s (using PyMarkups %s)') % (app_version, markups.__version__))
 		+'</b></p>' + self.tr('Simple but powerful editor'
 		' for Markdown and reStructuredText')
-		+'</p><p>'+self.tr('Author: Dmitry Shachnev, 2011').replace('2011', '2011–2021')
+		+'</p><p>'+self.tr('Author: Dmitry Shachnev, 2011').replace('2011', '2011–2024')
 		+'<br><a href="https://github.com/retext-project/retext">GitHub</a> | '
 		+'<a href="https://daringfireball.net/projects/markdown/syntax">'
 		+self.tr('Markdown syntax')
